// automatically generated file.
#define Z3_MAJOR_VERSION   4
#define Z3_MINOR_VERSION   15
#define Z3_BUILD_NUMBER    1
#define Z3_REVISION_NUMBER 0

#define Z3_FULL_VERSION    "4.15.1.0 b665c99d0608fd392b951a04559191f97a51eb38 z3-4.8.4-9459-gb665c99d0"
#define Z3GITHASH b665c99d0608fd392b951a04559191f97a51eb38
